        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 20 <strong>control</strong><br>0,6,7,11,16,18,19,20,21,22,23,27,30,31,34,35,36,38,44,47';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>17</strong> miembros: 17 <br>4,9,10,12,13,17,24,26,28,29,39,40,41,42,46,49,50';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 14 <br>1,2,3,5,8,14,15,25,32,33,37,43,45,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 20 <strong>control</strong><br>0,6,7,11,16,18,19,20,21,22,23,27,30,31,34,35,36,38,44,47';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>17</strong> miembros: 17 <br>4,9,10,12,13,17,24,26,28,29,39,40,41,42,46,49,50';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 14 <br>1,2,3,5,8,14,15,25,32,33,37,43,45,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 20 <strong>control</strong><br>0,6,7,11,16,18,19,20,21,22,23,27,30,31,34,35,36,38,44,47';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>17</strong> miembros: 17 <br>4,9,10,12,13,17,24,26,28,29,39,40,41,42,46,49,50';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 14 <br>1,2,3,5,8,14,15,25,32,33,37,43,45,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 20 <strong>control</strong><br>0,6,7,11,16,18,19,20,21,22,23,27,30,31,34,35,36,38,44,47';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>17</strong> miembros: 17 <br>4,9,10,12,13,17,24,26,28,29,39,40,41,42,46,49,50';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 14 <br>1,2,3,5,8,14,15,25,32,33,37,43,45,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 20 <strong>control</strong><br>0,6,7,11,16,18,19,20,21,22,23,27,30,31,34,35,36,38,44,47';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>17</strong> miembros: 17 <br>4,9,10,12,13,17,24,26,28,29,39,40,41,42,46,49,50';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 14 <br>1,2,3,5,8,14,15,25,32,33,37,43,45,48';}
}
